@@ -1,6 +1,7 @@
 /*
     GNOME Commander - A GNOME based file manager
     Copyright (C) 2001-2006 Marcus Bjurman
+    Copyright (C) 2007-2011 Piotr Eljasiak
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -20,8 +21,6 @@
 #ifndef __GNOME_CMD_STATE_H__
 #define __GNOME_CMD_STATE_H__
 
-G_BEGIN_DECLS
-
 typedef struct {
     GnomeVFSURI *active_dir_uri;
     GnomeVFSURI *inactive_dir_uri;
@@ -31,6 +30,4 @@ typedef struct {
     GList *inactive_dir_selected_files;
 } GnomeCmdState;
 
-G_END_DECLS
-
 #endif //__GNOME_CMD_STATE_H__
