@@ -94,6 +94,7 @@ struct SearchFileData
     guint           len;
 };
 
+
 struct GnomeCmdSearchDialogPrivate
 {
     SearchData *data;                       // holds data needed by the search routines
@@ -133,7 +134,7 @@ inline void set_statusmsg (SearchData *data, gchar *msg)
 
 inline void search_file_data_free (SearchFileData  *searchfile_data)
 {
-    if (searchfile_data->handle != NULL)
+    if (searchfile_data->handle)
         gnome_vfs_close (searchfile_data->handle);
 
     g_free (searchfile_data->uri_str);
@@ -150,7 +151,7 @@ static SearchFileData *read_search_file (SearchData *data, SearchFileData *searc
 
     GnomeVFSResult  result;
 
-    if (searchfile_data == NULL)
+    if (!searchfile_data)
     {
         searchfile_data          = g_new0 (SearchFileData, 1);
         searchfile_data->uri_str = gnome_cmd_file_get_uri_str (f);
@@ -222,14 +223,14 @@ static SearchFileData *read_search_file (SearchData *data, SearchFileData *searc
  */
 inline gboolean content_matches (GnomeCmdFile *f, SearchData *data)
 {
-    gint   ret = REG_NOMATCH;
+    gint ret = REG_NOMATCH;
 
     if (f->info->size > 0)
     {
         regmatch_t       match;
         SearchFileData  *search_file = NULL;
 
-        while ((search_file = read_search_file (data, search_file, f)) != NULL)
+        while ((search_file = read_search_file (data, search_file, f)))
         {
             ret = regexec (data->content_regex, data->search_mem, 1, &match, 0);
             // stop on first match
@@ -273,7 +274,6 @@ static void search_dir_r (GnomeCmdDir *dir, SearchData *data)
         g_mutex_unlock (data->pdata.mutex);
     }
 
-
     // If the stop button was pressed let's abort here
     if (data->stopped)
         return;
@@ -324,7 +324,7 @@ static void search_dir_r (GnomeCmdDir *dir, SearchData *data)
 
                 // the file matched the search criteria, lets add it to the list
                 g_mutex_lock (data->pdata.mutex);
-                data->pdata.files = g_list_append (data->pdata.files, f);
+                data->pdata.files = g_list_append (data->pdata.files, gnome_cmd_file_ref (f));
                 g_mutex_unlock (data->pdata.mutex);
 
                 // also ref each directory that has a matching file
@@ -377,7 +377,8 @@ static gpointer perform_search_operation (SearchData *data)
 
 static gboolean update_search_status_widgets (SearchData *data)
 {
-    g_mutex_lock (data->pdata.mutex);
+    if (data->pdata.mutex)
+        g_mutex_lock (data->pdata.mutex);
 
     // Add all files found since last update to the list
     for (GList *files = data->pdata.files; files; files = files->next)
@@ -385,7 +386,7 @@ static gboolean update_search_status_widgets (SearchData *data)
 
     if (data->pdata.files)
     {
-        g_list_free (data->pdata.files);
+        gnome_cmd_file_list_free (data->pdata.files);
         data->pdata.files = NULL;
     }
 
@@ -395,7 +396,8 @@ static gboolean update_search_status_widgets (SearchData *data)
     // Update the progress bar
     progress_bar_update (data->dialog->priv->pbar, PBAR_MAX);
 
-    g_mutex_unlock (data->pdata.mutex);
+    if (data->pdata.mutex)
+        g_mutex_unlock (data->pdata.mutex);
 
     if (data->search_done)
     {
@@ -447,8 +449,8 @@ static gboolean join_thread_func (SearchData *data)
     if (data->thread)
         g_thread_join (data->thread);
 
-    if (data->pdata.mutex != NULL)
-      g_mutex_free (data->pdata.mutex);
+    if (data->pdata.mutex)
+        g_mutex_free (data->pdata.mutex);
 
     g_free (data->search_mem);
 
@@ -473,7 +475,7 @@ static void on_dialog_destroy (GnomeCmdSearchDialog *dialog, gpointer user_data)
         g_timeout_add (1, (GSourceFunc) join_thread_func, data);
 
         // Unref all directories which contained matching files from last search
-        if (data->pdata.mutex != NULL)
+        if (data->pdata.mutex)
         {
             g_mutex_lock (data->pdata.mutex);
             if (data->match_dirs)
@@ -495,7 +497,7 @@ static void on_dialog_size_allocate (GtkWidget *widget, GtkAllocation *allocatio
 }
 
 
-static gboolean start_search (GnomeCmdSearchDialog *dialog)
+static gboolean start_generic_search (GnomeCmdSearchDialog *dialog)
 {
     SearchData *data = dialog->priv->data;
 
@@ -532,9 +534,6 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
 
     dialog->priv->result_list->remove_all_files();
 
-    gtk_widget_set_sensitive (data->dialog->priv->search_button, FALSE);
-    gtk_widget_set_sensitive (data->dialog->priv->stop_button, TRUE);
-
     // create an re for file name matching
     GtkWidget *regex_radio = lookup_widget (GTK_WIDGET (dialog), "regex_radio");
 
@@ -549,8 +548,8 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
         regcomp (data->content_regex, data->content_pattern, data->case_sens ? 0 : REG_ICASE);
     }
 
-    if (dialog->priv->data->search_mem == NULL)
-        dialog->priv->data->search_mem = (gchar *) g_malloc (SEARCH_BUFFER_SIZE);
+    if (!data->search_mem)
+        data->search_mem = (gchar *) g_malloc (SEARCH_BUFFER_SIZE);
 
     // start the search
     GnomeCmdPath *path = gnome_cmd_con_create_path (dialog->priv->con, data->dir);
@@ -559,15 +558,14 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
 
     data->search_done = FALSE;
 
-    if (data->pdata.mutex == NULL)
-      data->pdata.mutex = g_mutex_new ();
+    if (!data->pdata.mutex)
+        data->pdata.mutex = g_mutex_new ();
 
     data->thread = g_thread_create ((GThreadFunc) perform_search_operation, data, TRUE, NULL);
 
     gtk_widget_show (data->dialog->priv->pbar);
-    data->update_gui_timeout_id = g_timeout_add (gnome_cmd_data.gui_update_rate,
-                                                 (GSourceFunc) update_search_status_widgets,
-                                                 dialog->priv->data);
+    data->update_gui_timeout_id = g_timeout_add (gnome_cmd_data.gui_update_rate, (GSourceFunc) update_search_status_widgets, data);
+
     return FALSE;
 }
 
@@ -578,10 +576,11 @@ static gboolean start_search (GnomeCmdSearchDialog *dialog)
  */
 static void on_search (GtkButton *button, GnomeCmdSearchDialog *dialog)
 {
-    g_timeout_add (1, (GSourceFunc) start_search, dialog);
+    g_timeout_add (1, (GSourceFunc) start_generic_search, dialog);
 
-    gtk_widget_set_sensitive (dialog->priv->search_button, FALSE);
     gtk_widget_set_sensitive (dialog->priv->goto_button, FALSE);
+    gtk_widget_set_sensitive (dialog->priv->stop_button, TRUE);
+    gtk_widget_set_sensitive (dialog->priv->search_button, FALSE);
 }
 
 
@@ -728,8 +727,8 @@ inline GtkWidget *create_label_with_mnemonic (GtkWidget *parent, const gchar *te
 {
     GtkWidget *label = gtk_label_new_with_mnemonic (text);
 
-    if (for_widget != NULL)
-      gtk_label_set_mnemonic_widget (GTK_LABEL (label), for_widget);
+    if (for_widget)
+        gtk_label_set_mnemonic_widget (GTK_LABEL (label), for_widget);
 
     gtk_widget_ref (label);
     gtk_object_set_data_full (GTK_OBJECT (parent), "label", label, (GtkDestroyNotify) gtk_widget_unref);
